==> seostudio-1.0.1.tar.gz: seostudio/src/Form/SeoStudioConfigForm.php <==
<?php

namespace Drupal\seostudio\Form;

use Drupal\Core\Cache\Cache;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;
use Drupal\Core\Extension\ModuleHandlerInterface;

/**
 * Configuration form for FlareGpt Metatags settings.
 */
class SeoStudioConfigForm extends ConfigFormBase {

  protected $moduleHandler;

  public function __construct(ModuleHandlerInterface $module_handler) {
    $this->moduleHandler = $module_handler;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['seostudio.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'seostudio_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('seostudio.settings');

    // Retrieve all node types
    $node_types = NodeType::loadMultiple();

    $form['tabs'] = [
      '#type' => 'vertical_tabs',
    ];

    foreach ($node_types as $bundle => $node_type) {
      $bundleConfig = $config->get($bundle) ?? [];
      
      $form[$bundle] = [
        '#type' => 'details',
        '#title' => $node_type->label(),
        '#group' => 'tabs',
        '#tree' => TRUE, // This is crucial for maintaining the structure
      ];

      // Add a checkbox to enable/disable FlareGpt for this node type
      $form[$bundle]['enabled'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Enable FlareGpt for @node_type', ['@node_type' => $node_type->label()]),
        '#default_value' => $bundleConfig['enabled'] ?? FALSE,
      ];

      // Check if the FlareGPT module is installed
      $flaregpt_installed = \Drupal::moduleHandler()->moduleExists('flaregpt');

      // Meta Image settings
      $form[$bundle]['meta_image'] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Meta Image Settings'),
        '#disabled' => !$flaregpt_installed,
      ];

      $form[$bundle]['meta_image']['meta_images'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Generate meta images'),
        '#description' => $this->t('Automatically generate meta images with FlareGpt.'),
        '#default_value' => isset($bundleConfig['meta_image']['meta_images']) ? $bundleConfig['meta_image']['meta_images'] : FALSE,
        '#disabled' => !$flaregpt_installed,
      ];

      if (!$flaregpt_installed) {
        $form[$bundle]['meta_image']['flaregpt_message'] = [
          '#type' => 'markup',
          '#markup' => $this->t('Download the FlareGPT module for these pro features (<a href="https://www.drupal.org/project/seostudio" target="_blank">https://www.drupal.org/project/seostudio</a>).'),
          '#prefix' => '<div class="messages messages--info">',
          '#suffix' => '</div>',
        ];
      }

      $form[$bundle]['meta_image']['image_token'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Image Token'),
        '#description' => $this->t('Use a token that represents the main image field on your content type. E.g. [node:field_overview_image:entity:field_media_image:entity:url].'),
        '#default_value' => isset($bundleConfig['meta_image']['image_token']) ? $bundleConfig['meta_image']['image_token'] : '',
        '#autocomplete_route_parameters' => ['bundle' => $bundle],
        '#disabled' => !$flaregpt_installed,
      ];

      // Add the new Schema.org pane
      $form[$bundle]['schema_org'] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Schema.org Settings'),
        '#disabled' => !$flaregpt_installed,
      ];

      $form[$bundle]['schema_org']['jsonld'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Enable JSON-LD for @node_type', ['@node_type' => $node_type->label()]),
        '#default_value' => isset($bundleConfig['schema_org']['jsonld']) ? $bundleConfig['schema_org']['jsonld'] : FALSE,
        '#description' => $this->t('<p>JSON-LD (JavaScript Object Notation for Linked Data) is a method of embedding structured data in web pages. It helps search engines understand the content of your site better, potentially improving your search engine results and enabling rich snippets.</p>'),
        '#disabled' => !$flaregpt_installed,
      ];

      if (!$flaregpt_installed) {
        $form[$bundle]['schema_org']['flaregpt_message'] = [
          '#type' => 'markup',
          '#markup' => $this->t('Download the FlareGPT module for these pro features (<a href="https://www.drupal.org/project/seostudio" target="_blank">https://www.drupal.org/project/seostudio</a>).'),
          '#prefix' => '<div class="messages messages--info">',
          '#suffix' => '</div>',
        ];
      }

    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $config = $this->config('seostudio.settings');
    $values = $form_state->getValues();

    foreach ($values as $bundle => $bundleConfig) {
      if (is_array($bundleConfig)) {
        $config->set($bundle, $bundleConfig);
      }
    }

    $config->save();
    parent::submitForm($form, $form_state);
  }
}

==> seostudio-1.0.2.tar.gz: seostudio/src/Form/SeoStudioConfigForm.php <==
<?php

namespace Drupal\seostudio\Form;

use Drupal\Core\Cache\Cache;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;
use Drupal\Core\Extension\ModuleHandlerInterface;

/**
 * Configuration form for FlareGpt Metatags settings.
 */
class SeoStudioConfigForm extends ConfigFormBase {

  protected $moduleHandler;

  public function __construct(ModuleHandlerInterface $module_handler) {
    $this->moduleHandler = $module_handler;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['seostudio.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'seostudio_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('seostudio.settings');

    // Retrieve all node types
    $node_types = NodeType::loadMultiple();

    $form['tabs'] = [
      '#type' => 'vertical_tabs',
    ];

    foreach ($node_types as $bundle => $node_type) {
      $bundleConfig = $config->get($bundle) ?? [];
      
      $form[$bundle] = [
        '#type' => 'details',
        '#title' => $node_type->label(),
        '#group' => 'tabs',
        '#tree' => TRUE, // This is crucial for maintaining the structure
      ];

      // Add a checkbox to enable/disable FlareGpt for this node type
      $form[$bundle]['enabled'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Enable SEO Studio for @node_type', ['@node_type' => $node_type->label()]),
        '#default_value' => $bundleConfig['enabled'] ?? FALSE,
        '#description' => $this->t('If enabled, users with permission "administer meta tags" will see a SEO tab in their primary tabs.'),
      ];

      // Check if the FlareGPT module is installed
      $flaregpt_installed = \Drupal::moduleHandler()->moduleExists('flaregpt');

      // Meta Image settings
      $form[$bundle]['meta_image'] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Meta Image Settings'),
        '#disabled' => !$flaregpt_installed,
      ];

      $form[$bundle]['meta_image']['meta_images'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Generate meta images'),
        '#description' => $this->t('Automatically generate meta images with FlareGpt.'),
        '#default_value' => isset($bundleConfig['meta_image']['meta_images']) ? $bundleConfig['meta_image']['meta_images'] : FALSE,
        '#disabled' => !$flaregpt_installed,
      ];

      if (!$flaregpt_installed) {
        $form[$bundle]['meta_image']['flaregpt_message'] = [
          '#type' => 'markup',
          '#markup' => $this->t('Generating tags requires pro features (<a href="https://www.drupal.org/project/seostudio" target="_blank">Read more</a>).'),
          '#prefix' => '<div class="messages messages--info">',
          '#suffix' => '</div>',
        ];
      }

      $form[$bundle]['meta_image']['image_token'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Image Token'),
        '#description' => $this->t('Use a token that represents the main image field on your content type. E.g. [node:field_overview_image:entity:field_media_image:entity:url].'),
        '#default_value' => isset($bundleConfig['meta_image']['image_token']) ? $bundleConfig['meta_image']['image_token'] : '',
        '#autocomplete_route_parameters' => ['bundle' => $bundle],
        '#disabled' => !$flaregpt_installed,
      ];

      // Add the new Schema.org pane
      $form[$bundle]['schema_org'] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Schema.org Settings'),
        '#disabled' => !$flaregpt_installed,
      ];

      $form[$bundle]['schema_org']['jsonld'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Enable JSON-LD for @node_type', ['@node_type' => $node_type->label()]),
        '#default_value' => isset($bundleConfig['schema_org']['jsonld']) ? $bundleConfig['schema_org']['jsonld'] : FALSE,
        '#description' => $this->t('<p>JSON-LD (JavaScript Object Notation for Linked Data) is a method of embedding structured data in web pages. It helps search engines understand the content of your site better, potentially improving your search engine results and enabling rich snippets.</p>'),
        '#disabled' => !$flaregpt_installed,
      ];

      if (!$flaregpt_installed) {
        $form[$bundle]['schema_org']['flaregpt_message'] = [
          '#type' => 'markup',
          '#markup' => $this->t('Generating tags requires pro features (<a href="https://www.drupal.org/project/seostudio" target="_blank">Read more</a>).'),
          '#prefix' => '<div class="messages messages--info">',
          '#suffix' => '</div>',
        ];
      }

    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $config = $this->config('seostudio.settings');
    $values = $form_state->getValues();

    foreach ($values as $bundle => $bundleConfig) {
      if (is_array($bundleConfig)) {
        $config->set($bundle, $bundleConfig);
      }
    }

    $config->save();
    parent::submitForm($form, $form_state);
  }
}
